<?php

namespace Drupal\mautic_paragraph\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Url;
use Drupal\mautic_paragraph\MauticParagraphApi;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * MauticCallbackController for OAuth authorization callback.
 */
class MauticCallbackController extends ControllerBase {

  /**
   * The MauticApi service.
   *
   * @var \Drupal\mautic_paragraph\MauticParagraphApi
   */
  protected $mauticParagraphApi;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a MauticCallbackController object.
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger interface.
   * @param \Drupal\mautic_paragraph\MauticParagraphApi $mauticParagraphApi
   *   The MauticApi service.
   */
  public function __construct(MessengerInterface $messenger, MauticParagraphApi $mauticParagraphApi) {
    $this->messenger = $messenger;
    $this->mauticParagraphApi = $mauticParagraphApi;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('messenger'),
      $container->get('mautic_paragraph_api')
    );
  }

  /**
   * Callback function for Mautic OAuth connection.
   */
  public function callback() {
    try {
      $this->mauticParagraphApi->createMauticProvider();
      $this->messenger->addStatus($this->t('Succesfully connected with OAuth2 authorization!'));
    }
    catch (\Exception $e) {
      $body = $e->getResponse()->getBody();
      $error_message = json_decode($body, TRUE);
      foreach ($error_message['errors'] as $error_item) {
        $this->messenger->addError('Error status ' . $e->getCode() . ' : ' . $error_item['message']);
      }
      watchdog_exception('error', $e);

    }
    return new Redirectresponse(Url::fromRoute('mautic_paragraph.route_settings')->setAbsolute()->toString());
  }

}
